==> patentgpt_extract-0.1.0.tar.gz: patentgpt_extract-0.1.0/setup.py <==
from setuptools import setup, find_packages

setup(
    name="patentgpt_extract",
    version="0.1.0",
    description="A package for downloading and analysisng us patents.",
    author="Armin Norouzi",
    author_email="arminnorouzi2016@gmail.com.com",
    packages=["patentgpt"],
    package_dir={"": "src"},
    install_requires=[
        "aiohttp==3.8.5",
        "aiosignal==1.3.1",
        "anyio==3.7.1",
        "asttokens==2.2.1",
        "async-timeout==4.0.2",
        "attrs==23.1.0",
        "backcall==0.2.0",
        "backoff==2.2.1",
        "beautifulsoup4==4.12.2",
        "certifi==2023.7.22",
        "cffi==1.15.1",
        "chardet==5.1.0",
        "charset-normalizer==3.2.0",
        "chroma-hnswlib==0.7.1",
        "chromadb==0.4.3",
        "click==8.1.6",
        "colorama==0.4.6",
        "coloredlogs==15.0.1",
        "comm==0.1.3",
        "cryptography==41.0.2",
        "dataclasses-json==0.5.13",
        "debugpy==1.6.7",
        "decorator==5.1.1",
        "et-xmlfile==1.1.0",
        "executing==1.2.0",
        "faiss-cpu==1.7.4",
        "fastapi==0.99.1",
        "filetype==1.2.0",
        "flatbuffers==23.5.26",
        "frozenlist==1.4.0",
        "greenlet==2.0.2",
        "h11==0.14.0",
        "httptools==0.6.0",
        "humanfriendly==10.0",
        "idna==3.4",
        "importlib-resources==6.0.0",
        "ipykernel==6.25.0",
        "ipython==8.14.0",
        "jedi==0.18.2",
        "joblib==1.3.1",
        "jupyter_client==8.3.0",
        "jupyter_core==5.3.1",
        "kor==0.13.0",
        "langchain==0.0.246",
        "langsmith==0.0.15",
        "lxml==4.9.3",
        "Markdown==3.4.4",
        "marshmallow==3.20.1",
        "matplotlib-inline==0.1.6",
        "monotonic==1.6",
        "mpmath==1.3.0",
        "msg-parser==1.2.0",
        "multidict==6.0.4",
        "mypy-extensions==1.0.0",
        "nest-asyncio==1.5.6",
        "nltk==3.8.1",
        "numexpr==2.8.4",
        "numpy==1.25.1",
        "olefile==0.46",
        "onnxruntime==1.15.1",
        "openai==0.27.8",
        "openapi-schema-pydantic==1.2.4",
        "openpyxl==3.1.2",
        "overrides==7.3.1",
        "packaging==23.1",
        "pandas==1.5.3",
        "parso==0.8.3",
        "pdf2image==1.16.3",
        "pdfminer.six==20221105",
        "pickleshare==0.7.5",
        "Pillow==10.0.0",
        "platformdirs==3.9.1",
        "posthog==3.0.1",
        "prompt-toolkit==3.0.39",
        "protobuf==4.23.4",
        "psutil==5.9.5",
        "pulsar-client==3.2.0",
        "pure-eval==0.2.2",
        "pycodestyle==2.10.0",
        "pycparser==2.21",
        "pydantic==1.10.12",
        "Pygments==2.15.1",
        "pypandoc==1.11",
        "PyPika==0.48.9",
        "pyreadline3==3.4.1",
        "python-dateutil==2.8.2",
        "python-docx==0.8.11",
        "python-dotenv==1.0.0",
        "python-magic==0.4.27",
        "python-pptx==0.6.21",
        "pytz==2023.3",
        "pywin32==306",
        "PyYAML==6.0.1",
        "pyzmq==25.1.0",
        "regex==2023.6.3",
        "requests==2.31.0",
        "six==1.16.0",
        "sniffio==1.3.0",
        "soupsieve==2.4.1",
        "SQLAlchemy==2.0.19",
        "stack-data==0.6.2",
        "starlette==0.27.0",
        "sympy==1.12",
        "tabulate==0.9.0",
        "tenacity==8.2.2",
        "tiktoken==0.4.0",
        "tokenizers==0.13.3",
        "tornado==6.3.2",
        "tqdm==4.65.0",
        "traitlets==5.9.0",
        "typing-inspect==0.9.0",
        "typing_extensions==4.7.1",
        "tzdata==2023.3",
        "unstructured==0.8.6",
        "urllib3==2.0.4",
        "uvicorn==0.23.1",
        "watchfiles==0.19.0",
        "wcwidth==0.2.6",
        "websockets==11.0.3",
        "xlrd==2.0.1",
        "XlsxWriter==3.1.2",
        "yarl==1.9.2",
    ],
)

==> patentgpt_extract-0.1.1.tar.gz: patentgpt_extract-0.1.1/setup.py <==
from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

# python setup.py sdist
# twine upload dist/*

setup(
    name="patentgpt_extract",
    version="0.1.1",
    description="A package for downloading and analysisng us patents.",
    author="Armin Norouzi",
    author_email="arminnorouzi2016@gmail.com",
    packages=["patentgpt"],
    package_dir={"": "src"},
    long_description=long_description,
    long_description_content_type="text/markdown",
    project_urls={
        "Bug Tracker": "https://github.com/arminnorouzi/patentGPT/issues",
        "Source Code": "https://github.com/arminnorouzi/patentGPT",
    },
    install_requires=[
        "aiohttp==3.8.5",
        "aiosignal==1.3.1",
        "anyio==3.7.1",
        "asttokens==2.2.1",
        "async-timeout==4.0.2",
        "attrs==23.1.0",
        "backcall==0.2.0",
        "backoff==2.2.1",
        "beautifulsoup4==4.12.2",
        "certifi==2023.7.22",
        "cffi==1.15.1",
        "chardet==5.1.0",
        "charset-normalizer==3.2.0",
        "chroma-hnswlib==0.7.1",
        "chromadb==0.4.3",
        "click==8.1.6",
        "colorama==0.4.6",
        "coloredlogs==15.0.1",
        "comm==0.1.3",
        "cryptography==41.0.2",
        "dataclasses-json==0.5.13",
        "debugpy==1.6.7",
        "decorator==5.1.1",
        "et-xmlfile==1.1.0",
        "executing==1.2.0",
        "faiss-cpu==1.7.4",
        "fastapi==0.99.1",
        "filetype==1.2.0",
        "flatbuffers==23.5.26",
        "frozenlist==1.4.0",
        "greenlet==2.0.2",
        "h11==0.14.0",
        "httptools==0.6.0",
        "humanfriendly==10.0",
        "idna==3.4",
        "importlib-resources==6.0.0",
        "ipykernel==6.25.0",
        "ipython==8.14.0",
        "jedi==0.18.2",
        "joblib==1.3.1",
        "jupyter_client==8.3.0",
        "jupyter_core==5.3.1",
        "kor==0.13.0",
        "langchain==0.0.246",
        "langsmith==0.0.15",
        "lxml==4.9.3",
        "Markdown==3.4.4",
        "marshmallow==3.20.1",
        "matplotlib-inline==0.1.6",
        "monotonic==1.6",
        "mpmath==1.3.0",
        "msg-parser==1.2.0",
        "multidict==6.0.4",
        "mypy-extensions==1.0.0",
        "nest-asyncio==1.5.6",
        "nltk==3.8.1",
        "numexpr==2.8.4",
        "numpy==1.25.1",
        "olefile==0.46",
        "onnxruntime==1.15.1",
        "openai==0.27.8",
        "openapi-schema-pydantic==1.2.4",
        "openpyxl==3.1.2",
        "overrides==7.3.1",
        "packaging==23.1",
        "pandas==1.5.3",
        "parso==0.8.3",
        "pdf2image==1.16.3",
        "pdfminer.six==20221105",
        "pickleshare==0.7.5",
        "Pillow==10.0.0",
        "platformdirs==3.9.1",
        "posthog==3.0.1",
        "prompt-toolkit==3.0.39",
        "protobuf==4.23.4",
        "psutil==5.9.5",
        "pulsar-client==3.2.0",
        "pure-eval==0.2.2",
        "pycodestyle==2.10.0",
        "pycparser==2.21",
        "pydantic==1.10.12",
        "Pygments==2.15.1",
        "pypandoc==1.11",
        "PyPika==0.48.9",
        "pyreadline3==3.4.1",
        "python-dateutil==2.8.2",
        "python-docx==0.8.11",
        "python-dotenv==1.0.0",
        "python-magic==0.4.27",
        "python-pptx==0.6.21",
        "pytz==2023.3",
        "pywin32==306",
        "PyYAML==6.0.1",
        "pyzmq==25.1.0",
        "regex==2023.6.3",
        "requests==2.31.0",
        "six==1.16.0",
        "sniffio==1.3.0",
        "soupsieve==2.4.1",
        "SQLAlchemy==2.0.19",
        "stack-data==0.6.2",
        "starlette==0.27.0",
        "sympy==1.12",
        "tabulate==0.9.0",
        "tenacity==8.2.2",
        "tiktoken==0.4.0",
        "tokenizers==0.13.3",
        "tornado==6.3.2",
        "tqdm==4.65.0",
        "traitlets==5.9.0",
        "typing-inspect==0.9.0",
        "typing_extensions==4.7.1",
        "tzdata==2023.3",
        "unstructured==0.8.6",
        "urllib3==2.0.4",
        "uvicorn==0.23.1",
        "watchfiles==0.19.0",
        "wcwidth==0.2.6",
        "websockets==11.0.3",
        "xlrd==2.0.1",
        "XlsxWriter==3.1.2",
        "yarl==1.9.2",
    ],
)
